<div align="center">
  <img src="./assets/ml-vite.png" alt="logo">
</div>

<h1 align="center">ML-Vite</h1>

<p align="center">
This code mainly come from my data analysis competitions often uses.
</p>


## Install & load
```sh
git clone https://github.com/kazuki-komori/ml-vite.git
```

```py
import sys; sys.path.append("./ml-vite")
```

## test install
```sh
pip install -i https://test.pypi.org/simple/ ml-vite
```